@@ -1,6 +1,6 @@
 package Morpheus;
-BEGIN {
-  $Morpheus::VERSION = '0.44';
+{
+  $Morpheus::VERSION = '0.45';
 }
 use strict;
 sub morph ($;$);
@@ -150,6 +150,7 @@ our @plugins;
 
 require Data::Dump if $ENV{MORPHEUS_VERBOSE};
 our $indent = "";
+our $source = "";
 
 sub morph ($;$) {
     my ($main_ns, $type) = @_;
@@ -223,11 +224,12 @@ sub morph ($;$) {
 
             print "  $indent * ${plugin_name}->get($token)\n" if $ENV{MORPHEUS_VERBOSE};
             my $patch = do {
-                if ($stack->{"$plugin\0$main_ns\0$token"}) {
+                if ($stack->{"$plugin\0$source\0$main_ns\0$token"}) {
                     print "  $indent - skipped\n" if $ENV{MORPHEUS_VERBOSE};
                     next;
                 }
-                local $stack->{"$plugin\0$main_ns\0$token"} = 1;
+                local $stack->{"$plugin\0$source\0$main_ns\0$token"} = 1;
+                local $source = $main_ns;
                 $plugin->get($token);
             };
             print "  $indent - done\n" if $ENV{MORPHEUS_VERBOSE};
@@ -286,7 +288,7 @@ Morpheus - the ultimate configuration engine
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 SYNOPSIS
 
